@@ -27,33 +27,58 @@
 #include "wmctrl.h"
 #include "windows.h"
 #include "dsimple.h"
-int GetCurrentWorkspace()
+long GetCurrentWorkspace()
 {
    Atom atom, type;
    int format;
    unsigned long nitems,b;
-   unsigned char *properties = 0;
+   unsigned char *properties;
    long r;
-   atom = XInternAtom(display,"_NET_CURRENT_DESKTOP",False);
-   XGetWindowProperty(display, DefaultRootWindow(display), atom, 0, 1, False, 
-	 AnyPropertyType, &type, &format, &nitems, &b, &properties);
-   if(type != XA_CARDINAL)
+
+   if (IsCompiz)
    {
-      //printf("%d: nog eens ...\n",__LINE__);
+      properties = 0;
+      atom = XInternAtom(display,"_NET_DESKTOP_VIEWPORT",False);
+      XGetWindowProperty(display, DefaultRootWindow(display), atom, 0, 2, False, 
+	    AnyPropertyType, &type, &format, &nitems, &b, &properties);
+      if (type != XA_CARDINAL || nitems != 2)
+      {
+	 r = -1;
+      }
+      else
+      {
+	 // we have the x-y coordinates of the workspace, we hussle this
+	 // into one long number:
+	 r = ((long *)properties)[0]+(((long *)properties)[1]<<16);
+      }
       if(properties) XFree(properties);
-      atom = XInternAtom(display,"_WIN_WORKSPACE",False);
+   }
+   else
+   {
+      properties = 0;
+      atom = XInternAtom(display,"_NET_CURRENT_DESKTOP",False);
       XGetWindowProperty(display, DefaultRootWindow(display), atom, 0, 1, False, 
 	    AnyPropertyType, &type, &format, &nitems, &b, &properties);
+      if(type != XA_CARDINAL)
+      {
+	 //printf("%d: nog eens ...\n",__LINE__);
+	 if(properties) XFree(properties);
+	 atom = XInternAtom(display,"_WIN_WORKSPACE",False);
+	 XGetWindowProperty(display, DefaultRootWindow(display), atom, 0, 1, False, 
+	       AnyPropertyType, &type, &format, &nitems, &b, &properties);
+      }
+      if(type != XA_CARDINAL)
+	 r = -1;
+      else
+	 r = *(long *)properties;
+      if(properties) XFree(properties);
    }
-   if(type != XA_CARDINAL)
-      r = -1;
-   else
-      r = *(long *)properties;
-   //printf("wmctrl: %d: %ld %ld\n",__LINE__,nitems,r);
-   if(properties) XFree(properties);
-   return (int)r;
+   //printf("TD: wmctrl: %d: %ld %#lx\n",__LINE__,nitems,r);
+
+   return r;
 }
 
+
 int GetWindows(WinInfo **windows, int *nwin)
 {
    Atom atom, type;
@@ -67,7 +92,7 @@ int GetWindows(WinInfo **windows, int *nwin)
 	 AnyPropertyType, &type, &format, &nitems, &b, &properties);
    if(type != XA_WINDOW)
    {
-      printf("%d: nog eens ...\n",__LINE__);
+      //printf("%d: nog eens ...\n",__LINE__);
       if(properties) XFree(properties);
       atom = XInternAtom(display,"_WIN_CLIENT_LIST",False);
       XGetWindowProperty(display, DefaultRootWindow(display), atom, 0, 1000000, False, 
@@ -222,7 +247,7 @@ void printwindows(WinInfo *windows, int nwin)
    int i;
    for (i=0; i<nwin; i++)
    {
-      printf("id:%#lx ws:%d x:%d y:%d w:%d h:%d sticky:%d\n",w->id,w->ws,w->x,w->y,w->w,w->h,w->sticky);
+      printf("id:%#lx ws:%#lx x:%d y:%d w:%d h:%d sticky:%d\n",w->id,w->ws,w->x,w->y,w->w,w->h,w->sticky);
       w++;
    }
    return;
